@@ -512,7 +512,7 @@ namespace QuantLib {
         explicit LatentModel(
             const std::vector<std::vector<Real> >& factorsWeights, 
             const typename copulaType::initTraits& ini = 
-                copulaType::initTraits());
+                typename copulaType::initTraits());
         /*! Constructs a LM with an arbitrary number of latent variables 
           depending only on one random factor but contributing to each latent
           variable through different weights.
@@ -524,7 +524,7 @@ namespace QuantLib {
         */
         explicit LatentModel(const std::vector<Real>& factorsWeight,
             const typename copulaType::initTraits& ini = 
-                copulaType::initTraits());
+                typename copulaType::initTraits());
         /*! Constructs a LM with an arbitrary number of latent variables 
           depending only on one random factor with the same weight for all
           latent variables.
@@ -538,7 +538,7 @@ namespace QuantLib {
         */
         explicit LatentModel(Real correlSqr,
                              Size nVariables,
-                             const typename copulaType::initTraits& ini = copulaType::initTraits());
+                             const typename copulaType::initTraits& ini = typename copulaType::initTraits());
         /*! Constructs a LM with an arbitrary number of latent variables 
           depending only on one random factor with the same weight for all
           latent variables. The weight is observed and this constructor is
@@ -554,7 +554,7 @@ namespace QuantLib {
         explicit LatentModel(const Handle<Quote>& singleFactorCorrel,
             Size nVariables,
             const typename copulaType::initTraits& ini = 
-                copulaType::initTraits());
+                typename copulaType::initTraits());
 
         //! Provides values of the factors \f$ a_{i,k} \f$ 
         const std::vector<std::vector<Real> >& factorWeights() const {
